@@ -103,7 +103,11 @@ def set_logger(logger_name, add_handler=False, base_logger=False, add_to_console
         logger.addHandler(handler)
 
         logging.captureWarnings(True)
-        warnings.filterwarnings('default', category=DeprecationWarning)
+        if log_level == 'DEBUG':
+            warnings.filterwarnings('default', category=DeprecationWarning)
+        else:
+            warnings.filterwarnings('ignore', category=DeprecationWarning)
+
         warnings_logger = logging.getLogger("py.warnings")
         warnings_logger.addHandler(handler)
 
@@ -1080,9 +1084,9 @@ def get_plugins(plugin_type='daq_0Dviewer'):  # pragma: no cover
                     else:
                         importlib.import_module(f'{submodule.__package__}.daq_{plugin_type[4:6]}viewer_{mod["name"]}')
                     plugins_import.append(mod)
-                except Exception:  # pragma: no cover
+                except Exception as e:  # pragma: no cover
                     pass
-        except Exception:  # pragma: no cover
+        except Exception as e:  # pragma: no cover
             pass
 
     #add utility plugin for PID
