@@ -1,6 +1,6 @@
 from collections import OrderedDict
-from PyQt5.QtCore import QObject, pyqtSignal, pyqtSlot, QThread
-from PyQt5 import QtWidgets
+from qtpy.QtCore import QObject, Signal, Slot, QThread
+from qtpy import QtWidgets
 import time
 from pymodaq.daq_utils import daq_utils as utils
 
@@ -10,11 +10,11 @@ logger = utils.set_logger(utils.get_module_name(__file__))
 
 
 class ModulesManager(QObject):
-    detectors_changed = pyqtSignal(list)
-    actuators_changed = pyqtSignal(list)
-    det_done_signal = pyqtSignal(OrderedDict)
-    move_done_signal = pyqtSignal(OrderedDict)
-    timeout_signal = pyqtSignal(bool)
+    detectors_changed = Signal(list)
+    actuators_changed = Signal(list)
+    det_done_signal = Signal(OrderedDict)
+    move_done_signal = Signal(OrderedDict)
+    timeout_signal = Signal(bool)
 
     params = [
         {'title': 'Actuators/Detectors Selection', 'name': 'modules', 'type': 'group', 'children': [
@@ -69,6 +69,9 @@ class ModulesManager(QObject):
         self.grab_done_signals = []
         self.det_commands_signal = []
 
+        self.actuators_connected = False
+        self.detectors_connected = False
+
         self.set_actuators(actuators, selected_actuators)
         self.set_detectors(detectors, selected_detectors)
 
@@ -112,10 +115,18 @@ class ModulesManager(QObject):
     def detectors(self):
         return self.get_mods_from_names(self.selected_detectors_name)
 
+    @property
+    def detectors_all(self):
+        return self._detectors
+
     @property
     def actuators(self):
         return self.get_mods_from_names(self.selected_actuators_name, mod='act')
 
+    @property
+    def actuators_all(self):
+        return self._actuators
+
     @property
     def Ndetectors(self):
         return len(self.detectors)
@@ -241,6 +252,7 @@ class ModulesManager(QObject):
         if connect:
             for sig in [mod.move_done_signal for mod in self.actuators]:
                 sig.connect(slot)
+
         else:
             try:
                 for sig in [mod.move_done_signal for mod in self.actuators]:
@@ -248,7 +260,20 @@ class ModulesManager(QObject):
             except Exception as e:
                 logger.error(str(e))
 
+        self.actuators_connected = connect
+
     def connect_detectors(self, connect=True, slot=None):
+        """
+        Connect selected DAQ_Viewers's grab_done_signal to the given slot
+        Parameters
+        ----------
+        connect: (bool) if True, connect to the given slot (or default slot)
+                        if False, disconnect all detectors (not only the currently selected ones.
+                        This is made because when selected detectors changed if you only disconnect those ones,
+                        the previously connected ones will stay connected)
+
+        slot: (method) A method that should be connected
+        """
         if slot is None:
             slot = self.det_done
 
@@ -256,11 +281,15 @@ class ModulesManager(QObject):
             for sig in [mod.grab_done_signal for mod in self.detectors]:
                 sig.connect(slot)
         else:
-            try:
-                for sig in [mod.grab_done_signal for mod in self.detectors]:
+
+            for sig in [mod.grab_done_signal for mod in self.detectors_all]:
+                try:
                     sig.disconnect(slot)
-            except Exception as e:
-                logger.error(str(e))
+                except TypeError as e:
+                    # means the slot was not previously connected
+                    logger.info(str(e))
+
+        self.detectors_connected = connect
 
     def test_move_actuators(self):
         positions = dict()
@@ -281,11 +310,37 @@ class ModulesManager(QObject):
 
         self.connect_actuators(False)
 
-    def move_actuators(self, positions):
+    def move_actuators(self, positions, mode='abs', polling=True):
+        """will apply positions to each currently selected actuators. By Default the mode is absolute but can be
+
+        Parameters
+        ----------
+        positions: (list) the list of position to apply. Its length must be equal to the number of selected actutors
+        mode: (str) either 'abs' for absolute positionning or 'rel' for relative
+        poll: (bool) if True will wait for the selected actuators to reach their target positions (they have to be
+        connected to a method checking for the position and letting the programm know the move is done (default
+        connection is this object `move_done` method)
+
+        Returns
+        -------
+        (OrderedDict) with the selected actuators's name as key and current actuators's value as value
+
+        See Also
+        --------
+        move_done
+        """
         self.move_done_positions = OrderedDict()
         self.move_done_flag = False
         self.settings.child(('move_done')).setValue(self.move_done_flag)
 
+        if mode == 'abs':
+            command = 'move_Abs'
+        elif mode == 'rel':
+            command = 'move_Rel'
+        else:
+            logger.error(f'Invalid positioning mode: {mode}')
+            return self.move_done_positions
+
         if not hasattr(positions, '__iter__'):
             positions = [positions]
 
@@ -294,25 +349,25 @@ class ModulesManager(QObject):
                 for k in positions:
                     act = self.get_mod_from_name(k, 'act')
                     if act is not None:
-                        act.command_stage.emit(utils.ThreadCommand(command="move_Abs", attributes=[positions[k]]))
+                        act.command_stage.emit(utils.ThreadCommand(command=command, attributes=[positions[k], polling]))
             else:
                 for ind, act in enumerate(self.actuators):
-                    act.command_stage.emit(utils.ThreadCommand(command="move_Abs", attributes=[positions[ind]]))
+                    act.command_stage.emit(utils.ThreadCommand(command=command, attributes=[positions[ind], polling]))
 
         else:
             logger.error('Invalid number of positions compared to selected actuators')
             return self.move_done_positions
 
         tzero = time.perf_counter()
+        if polling:
+            while not self.move_done_flag:  # polling move done
 
-        while not self.move_done_flag: #polling move done
-
-            QtWidgets.QApplication.processEvents()
-            if time.perf_counter() - tzero > self.timeout:
-                self.timeout_signal.emit(True)
-                logger.error('Timeout Fired during waiting for data to be acquired')
-                break
-            QThread.msleep(20)
+                QtWidgets.QApplication.processEvents()
+                if time.perf_counter() - tzero > self.timeout:
+                    self.timeout_signal.emit(True)
+                    logger.error('Timeout Fired during waiting for data to be acquired')
+                    break
+                QThread.msleep(20)
 
         self.move_done_signal.emit(self.move_done_positions)
         return self.move_done_positions
@@ -324,7 +379,7 @@ class ModulesManager(QObject):
             pos.append(positions_as_dict[act])
         return pos
 
-    pyqtSlot(str, float)
+    Slot(str, float)
 
     def move_done(self, name, position):
         """
@@ -335,11 +390,11 @@ class ModulesManager(QObject):
 
             if len(self.move_done_positions.items()) == len(self.actuators):
                 self.move_done_flag = True
-                self.settings.child(('move_done')).setValue(self.move_done_flag)
+                self.settings.child('move_done').setValue(self.move_done_flag)
         except Exception as e:
             logger.exception(str(e))
 
-    @pyqtSlot(OrderedDict)
+    @Slot(OrderedDict)
     def det_done(self, data):
         try:
             if data['name'] not in list(self.det_done_datas.keys()):
@@ -355,7 +410,7 @@ if __name__ == '__main__':
     import sys
 
     app = QtWidgets.QApplication(sys.argv)
-    from PyQt5.QtCore import QThread
+    from qtpy.QtCore import QThread
     from pymodaq.daq_utils.gui_utils import DockArea
     from pyqtgraph.dockarea import Dock
     from pymodaq.daq_viewer.daq_viewer_main import DAQ_Viewer
