@@ -1,26 +1,30 @@
 import os
 import sys
-from PyQt5.QtCore import QObject, pyqtSignal
-from PyQt5 import QtGui, QtWidgets
+
+import pymodaq.daq_utils.config
+from qtpy.QtCore import QObject, Signal
+from qtpy import QtGui, QtWidgets
 
 from pymodaq.daq_utils.parameter import ioxml
 from pymodaq.daq_utils import daq_utils as utils
 from pymodaq.daq_utils.gui_utils import select_file
 from pyqtgraph.parametertree import Parameter, ParameterTree, registerParameterType
-from pymodaq.daq_utils.parameter.pymodaq_ptypes import GroupParameterCustom as GroupParameter
+from pyqtgraph.parametertree.parameterTypes.basetypes import GroupParameter
 
 logger = utils.set_logger(utils.get_module_name(__file__))
-remote_path = utils.get_set_remote_path()
+remote_path = pymodaq.daq_utils.config.get_set_remote_path()
 remote_types = ['ShortCut', 'Joystick']
 
 actuator_actions = ['move_Rel', 'move_Rel_p', 'move_Rel_m']
 detector_actions = ['snap', 'grab', 'stop']
-
+remote_types = ['Keyboard', 'Joystick']
 try:
     import pygame
+    is_pygame = True
 except ModuleNotFoundError as e:
     remote_types.pop(remote_types.index('Joystick'))
     logger.warning('Could not load pygame module, no joystick configurable')
+    is_pygame = False
 
 
 class ScalableGroupRemote(GroupParameter):
@@ -47,9 +51,9 @@ class ScalableGroupRemote(GroupParameter):
         else:
             newindex = max(child_indexes) + 1
 
-        params = [{'title': 'Action:', 'name': 'action', 'type': 'list', 'value': typ, 'values': self.opts['addList']},
+        params = [{'title': 'Action:', 'name': 'action', 'type': 'list', 'value': typ, 'limits': self.opts['addList']},
                   {'title': 'Remote:', 'name': 'remote_type', 'type': 'list', 'value': 'Keyboard',
-                   'values': ['Keyboard', 'Joystick']},
+                   'limits': remote_types},
                   ]
         params.extend([
             {'title': 'Set Shortcut:', 'name': 'set_shortcut', 'type': 'bool_push', 'label': 'Set',
@@ -59,7 +63,7 @@ class ScalableGroupRemote(GroupParameter):
              'value': False, 'visible': False},
 
             {'title': 'Joystick ID:', 'name': 'joystickID', 'type': 'int', 'value': -1, 'visible': False},
-            {'title': 'Actionner type:', 'name': 'actionner_type', 'type': 'list', 'values': ['Axis', 'Button', 'Hat'],
+            {'title': 'Actionner type:', 'name': 'actionner_type', 'type': 'list', 'limits': ['Axis', 'Button', 'Hat'],
              'visible': False},
             {'title': 'Actionner ID:', 'name': 'actionnerID', 'type': 'int', 'value': -1, 'visible': False},
         ])
@@ -108,7 +112,7 @@ class ScalableGroupModules(GroupParameter):
 
         params = [
             {'title': 'Actions:', 'name': 'actions', 'type': 'groupremote', 'value': typ,
-             'values': self.opts['addList'], 'addList': addlist},
+             'limits': self.opts['addList'], 'addList': addlist},
         ]
 
         # for param in params:
@@ -171,9 +175,10 @@ class JoystickButtonsSelection(QtWidgets.QDialog):
         # width, height = 64 * 10, 64 * 8
         # self.screen = pygame.display.set_mode((width, height))
         joystick_count = pygame.joystick.get_count()
+        self.joysticks = []
         for ind in range(joystick_count):
-            joystick = pygame.joystick.Joystick(ind)
-            joystick.init()
+            self.joysticks.append(pygame.joystick.Joystick(ind))
+            self.joysticks[-1].init()
         self.startTimer(10)
 
     def timerEvent(self, event):
@@ -245,7 +250,7 @@ class JoystickButtonsSelection(QtWidgets.QDialog):
 
 
 class RemoteManager(QObject):
-    remote_changed = pyqtSignal(dict)
+    remote_changed = Signal(dict)
 
     def __init__(self, actuators=[], detectors=[], msgbox=False):
         super().__init__()
@@ -464,7 +469,7 @@ if __name__ == '__main__':
     actuators = ['act0', 'act1', 'act2']
     detectors = ['det0', 'det1', 'det2']
     app = QtWidgets.QApplication(sys.argv)
-    # prog = RemoteManager(actuators=actuators, detectors=detectors, msgbox=True)
+    #prog = RemoteManager(actuators=actuators, detectors=detectors, msgbox=True)
     msgBox = JoystickButtonsSelection()
     ret = msgBox.exec()
     sys.exit(app.exec_())
