@@ -12,6 +12,7 @@ from pymodaq.daq_utils.plotting.scan_selector import ScanSelector
 import pymodaq.daq_utils.daq_utils as utils
 import pymodaq.daq_utils.gui_utils as gutils
 from pymodaq.daq_utils.parameter import utils as putils
+from pymodaq.daq_utils import math_utils as mutils
 from pymodaq.daq_utils.plotting.utils.plot_utils import QVector
 from pyqtgraph.parametertree import Parameter, ParameterTree
 import pymodaq.daq_utils.parameter.pymodaq_ptypes as pymodaq_types  # to be placed after importing Parameter
@@ -149,7 +150,7 @@ class ScanParameters:
             axes_indexes = np.zeros_like(positions, dtype=int)
             for ind in range(positions.shape[0]):
                 for ind_pos, pos in enumerate(positions[ind]):
-                    axes_indexes[ind, ind_pos] = utils.find_index(axes_unique[ind_pos], pos)[0][0]
+                    axes_indexes[ind, ind_pos] = mutils.find_index(axes_unique[ind_pos], pos)[0][0]
 
             return ScanInfo(Nsteps=positions.shape[0], axes_unique=axes_unique,
                             axes_indexes=axes_indexes, positions=positions, adaptive_loss=self.adaptive_loss)
@@ -167,7 +168,7 @@ class ScanParameters:
             if self.positions is not None:
                 positions = self.positions
             else:
-                positions = utils.linspace_step(self.starts[0], self.stops[0], self.steps[0])
+                positions = mutils.linspace_step(self.starts[0], self.stops[0], self.steps[0])
 
             if self.scan_subtype == "Linear":
                 self.scan_info = self.get_info_from_positions(positions)
@@ -505,7 +506,7 @@ class Scanner(QObject):
             logger.exception(str(e))
 
         if scan_type == 'Sequential' or scan_type == 'Tabular':
-            self.table_view.horizontalHeader().setResizeMode(QtWidgets.QHeaderView.ResizeToContents)
+            self.table_view.horizontalHeader().setSectionResizeMode(QtWidgets.QHeaderView.ResizeToContents)
             self.table_view.horizontalHeader().setStretchLastSection(True)
             self.table_view.setSelectionBehavior(QtWidgets.QTableView.SelectRows)
             self.table_view.setSelectionMode(QtWidgets.QTableView.SingleSelection)
