@@ -23,8 +23,9 @@ class ViewerPointList(QObject):
     @Slot(float, float)
     def double_click_action(self, posx, posy):
         xs, ys = self.viewer.scale_axis(posx, posy)
-        data_at = self.viewer.get_data_at_along(posx, posy)['red'].int_data
-        self.table_model.add_data(self.table_view.currentIndex().row() + 1, [xs, ys, data_at])
+        data_at = self.viewer.get_data_at('red', (posx, posy))
+        if data_at is not None:
+            self.table_model.add_data(self.table_view.currentIndex().row() + 1, [xs, ys, data_at])
 
     def setData(self, data):
         self.viewer.setImage(data_red=data)
@@ -57,7 +58,7 @@ class ViewerPointList(QObject):
         self.table_view = get_widget_from_tree(self.settings_tree, TableViewCustom)[0]
         self.settings.child(('tabular_table')).setValue(self.table_model)
 
-        self.table_view.horizontalHeader().setResizeMode(QtWidgets.QHeaderView.ResizeToContents)
+        self.table_view.horizontalHeader().setSectionResizeMode(QtWidgets.QHeaderView.ResizeToContents)
         self.table_view.horizontalHeader().setStretchLastSection(True)
         self.table_view.setSelectionBehavior(QtWidgets.QTableView.SelectRows)
         self.table_view.setSelectionMode(QtWidgets.QTableView.SingleSelection)
@@ -97,7 +98,8 @@ if __name__ == '__main__':
     y = (np.linspace(0, Ny - 1, Ny) - 10) * 2
     from pymodaq.daq_utils.daq_utils import gauss2D
 
-    data_red = 3 * gauss2D(x, 0.2 * Nx, Nx / 5, y, 0.3 * Ny, Ny / 5, 1, 90)
+    data_red = 3 * gauss2D(x, np.mean(x), (np.max(x)-np.min(x)) / 5, y, np.mean(y), (np.max(y)-np.min(y)) / 5, 1)
+    data_red += np.random.random(data_red.shape)
 
     viewer.setData(data_red)
     viewer.setXaxis(Axis(data=x, label='This is x axis', units='au'))
